@@ -53,6 +53,7 @@ def instantiate_send_ud_stock_job(job_config: dict) -> None:
 def instantiate_insert_price_semaphore_job(job_config: dict) -> None:
     """
     Instancia o job de envio dos preços para o banco semáforo
+
     Args:
         job_config: Configuração do job obtida na api do oking
     """
@@ -63,6 +64,7 @@ def instantiate_insert_price_semaphore_job(job_config: dict) -> None:
 def instantiate_send_price_job(job_config: dict) -> None:
     """
     Instancia o job de envio dos preços para a api okVendas
+
     Args:
         job_config: Configuração do job obtida na api do oking
     """
@@ -70,6 +72,27 @@ def instantiate_send_price_job(job_config: dict) -> None:
     price_jobs.job_send_prices(job_config)
 
 
+def instantiate_prices_list_job(job_config: dict) -> None:
+    """
+    Instancia o job de envio das listas de preço para o banco semáforo
+
+    Args:
+        job_config: Configuração do job obtida na api do oking
+    """
+    logger.info(job_config.get('job_name') + ' | Iniciando execucao')
+    price_jobs.job_prices_list(job_config)
+
+
+def instantiate_product_prices_list_job(job_config: dict) -> None:
+    """
+    Instancia o job dos produtos das listas de preço
+
+    Args:
+        job_config: Configuração do job obtida na api do oking
+    """
+    logger.info(job_config.get('job_name') + ' | Iniciando execucao')
+    price_jobs.job_products_prices_list(job_config)
+
 # endregion Precos
 
 
@@ -231,9 +254,16 @@ def get_job_from_name(job_name: str):
     # Preco
     elif job_name == 'insere_preco_produto_semaforo_job':
         return instantiate_insert_price_semaphore_job
+
     elif job_name == 'envia_preco_produtos_job':
         return instantiate_send_price_job
 
+    elif job_name == 'lista_preco_job':
+        return instantiate_prices_list_job
+
+    elif job_name == 'produto_lista_preco_job':
+        return instantiate_product_prices_list_job
+
     # Catalogacao
     elif job_name == 'envia_catalogo_produto_semaforo_job':
         return instantiate_insert_products_semaphore_job
