@@ -1,19 +1,17 @@
 import json
 import logging
 from typing import Optional, List
-
 import jsonpickle
 import requests
-
 import src
 from src.api.entities.cliente import Cliente
+from src.api.entities.lista_preco import ListaPreco, ListaPrecoResponse
 from src.entities.invoice import Invoice
 from src.entities.log import Log
 from src.entities.order import Queue, Order
 from src.entities.orderb2b import OrderB2B
 from src.entities.price import Price
-from src.entities.response import CatalogoResponse, PriceResponse, InvoiceResponse, TrackingResponse, StockResponse, \
-    ClientResponse
+from src.entities.response import CatalogoResponse, PriceResponse, InvoiceResponse, TrackingResponse, StockResponse, ClientResponse
 from src.entities.tracking import Tracking
 from src.entities.photos_sku import PhotosSku
 
@@ -350,3 +348,35 @@ def put_photos_sku(body: List[PhotosSku]):
     except Exception as ex:
         logger.error(f'Erro ao realizar PUT /v2/catalogo/fotos/sku na api okvendas {url}' + str(ex), exc_info=True)
         return False
+
+
+def put_price_lists(body: List[ListaPreco]) -> List[ListaPrecoResponse]:
+    try:
+        url = f'{src.client_data.get("url_api")}/catalogo/listapreco'
+        headers = {'Content-type': 'application/json',
+                   'Accept': 'application/json',
+                   'access-token': src.client_data.get('token_api')}
+        json_body = jsonpickle.encode(body, unpicklable=False)
+
+        response = requests.put(url, headers=headers, json=json.loads(json_body))
+        if response.ok:
+            res = jsonpickle.decode(response.content)
+            return [ListaPrecoResponse(**r) for r in res]
+        else:
+            raise response.content
+    except Exception as e:
+        logger.error(f'Erro ao realizar PUT /catalogo/listapreco na api okvendas {str(e)}')
+
+
+def put_price_lists_products(price_list_code: str, body: str) -> bool:
+    try:
+        url = f'{src.client_data.get("url_api")}/catalogo/listapreco/preco/lote?price_list_code={price_list_code}'
+        headers = {'Content-type': 'application/json',
+                   'Accept': 'application/json',
+                   'access-token': src.client_data.get('token_api')}
+        json_body = jsonpickle.encode(body, unpicklable=False)
+
+        response = requests.put(url, headers=headers, json=json.loads(json_body))
+        return response.ok
+    except Exception as e:
+        logger.error(f'Erro ao realizar PUT /catalogo/listapreco/preco/lote na api okvendas {str(e)}')
