@@ -3,7 +3,9 @@ from datetime import datetime
 
 class Client:
     def __init__(self, nome, razao_social, cpf, cnpj, email, telefone_residencial, telefone_celular, cep, tipo_logradouro, logradouro, numero, complemento, bairro, cidade, estado, referencia,
-                 cliente_erp, direcao, data_sincronizacao, codigo_ibge):
+                 cliente_erp, direcao, data_sincronizacao, codigo_ibge, inscricao_estadual, compra_liberada, site_pertencente, data_bloqueio):
+        self.belonging_site = site_pertencente
+        self.blocked_date = data_bloqueio
         self.name: str = nome
         self.company_name: str = razao_social
         self.cpf: str = cpf
@@ -24,3 +26,5 @@ class Client:
         self.direction: str = direcao
         self.sync_date: datetime = data_sincronizacao
         self.ibge_code: str = codigo_ibge
+        self.state_registration: str = inscricao_estadual
+        self.purchase_released: bool = compra_liberada
